kuroshiro library
Classes
- Kuroshiro
- Conversion system for Japanese text.
Enums
- ConvertMode
- Conversion modes for Japanese text.
- ConvertTo
- An enum representing the available conversion systems for Japanese text.
- RomanizationSystem
- An enum representing the available romanization systems for Japanese text.
- StringType
- Represents the type of characters present in a string.
Functions
-
getRomajiSystem(
RomanizationSystem system) → Map< String, String> -
getStrType(
String str) → StringType - Determines the type of characters present in a given string.
-
hasHiragana(
String str) → bool -
hasJapanese(
String str) → bool -
hasKana(
String str) → bool -
hasKanji(
String str) → bool -
hasKatakana(
String str) → bool -
isHiragana(
String char) → bool -
isJapanese(
String char) → bool -
isKana(
String char) → bool -
isKanji(
String char) → bool -
isKatakana(
String char) → bool -
kanaToHiragana(
String str) → String -
kanaToKatakana(
String str) → String -
kanaToRomaji(
String str, [RomanizationSystem system = RomanizationSystem.hepburn]) → String -
toRawHiragana(
String str) → String -
toRawKatakana(
String str) → String -
toRawRomaji(
String str, [RomanizationSystem system = RomanizationSystem.hepburn]) → String