RomanizationSystem enum

An enum representing the available romanization systems for Japanese text.

Inheritance
Available extensions

Values

nippon → const RomanizationSystem

Nippon system, also known as Nihon-shiki.

passport → const RomanizationSystem

Passport system, used in Japanese passports.

hepburn → const RomanizationSystem

Hepburn system, a common romanization system for Japanese.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RomanizationSystem>
A constant List of the values in this enum, in order of their declaration.